@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.0802';
+our $VERSION = '0.0900';
 
 use Carp;
 
@@ -70,16 +70,7 @@ sub parse {
     my $position = first_index { $_ eq $note } @notes;
     my $accidental;
     if ( $position == -1 ) {
-        if ( length($note) == 1 ) {
-            $position = first_index { $_ =~ /$note/ } @notes;
-            ( $accidental = $notes[$position] ) =~ s/^[A-G](.)$/$1/;
-            $accidental = $accidental eq '#' ? 'b' : '#';
-        }
-        else {
-            my $letter;
-            ( $letter, $accidental ) = $note =~ /^([A-G])(.)$/;
-            $position = first_index { $_ eq $letter } @notes;
-        }
+        ( $position, $accidental ) = _pos_acc( $note, $position, \@notes );
     }
     my $roman = $roman[$position];
 
@@ -115,7 +106,9 @@ sub parse {
             $decorator =~ s/[A-G][#b]?/$roman[$position]/;
         }
         else {
-            croak "Can't parse non-scale note in bass";
+            ( $position, $accidental ) = _pos_acc( $name, $position, \@notes );
+            my $bass = $accidental . $roman[$position];
+            $decorator =~ s/[A-G][#b]?/$bass/;
         }
     }
 
@@ -125,6 +118,25 @@ sub parse {
     return $roman;
 }
 
+sub _pos_acc {
+    my ( $note, $position, $notes ) = @_;
+
+    my $accidental;
+
+    if ( length($note) == 1 ) {
+        $position = first_index { $_ =~ /$note/ } @$notes;
+        ( $accidental = $notes->[$position] ) =~ s/^[A-G](.)$/$1/;
+        $accidental = $accidental eq '#' ? 'b' : '#';
+    }
+    else {
+        my $letter;
+        ( $letter, $accidental ) = $note =~ /^([A-G])(.)$/;
+        $position = first_index { $_ eq $letter } @$notes;
+    }
+
+    return $position, $accidental;
+}
+
 1;
 
 __END__
@@ -139,7 +151,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0802
+version 0.0900
 
 =head1 SYNOPSIS
 
@@ -156,6 +168,7 @@ version 0.0802
   $roman = $mtr->parse('CM');     # III (major)
   $roman = $mtr->parse('C');      # III (major)
   $roman = $mtr->parse('Cm9/G');  # iii9/VII (minor ninth with seven bass)
+  $roman = $mtr->parse('Cm9/Bb'); # iii9/bii (minor ninth with flat-two bass)
   $roman = $mtr->parse('D sus4'); # IV sus4
   $roman = $mtr->parse('DMaj7');  # IV maj7 (major seventh)
   $roman = $mtr->parse('E7');     # V7 (dominant seventh)
